@@ -6,6 +6,7 @@
 
 import json
 import os
+import sys
 
 import django
 from django.conf import settings
@@ -59,18 +60,34 @@ def test_runner(self):
                     if not line.startswith('#'):
                         req = json.loads(line)
 
+                        if getattr(settings, 'SMOKNUR_PRINT_REQUESTS', False):
+                            sys.stdout.write(
+                                ERROR_TEXT.format(
+                                    index,
+                                    f,
+                                    req['url'],
+                                    req['params']).encode('utf-8'))
+
                         try:
                             resp = self.client.post(
                                 req['url'],
                                 req['params']
                             )
                         except:
-                            print ERROR_TEXT.format(
-                                index,
-                                f,
-                                req['url'],
-                                req['params'])
+                            sys.stdout.write(
+                                ERROR_TEXT.format(
+                                    index,
+                                    f,
+                                    req['url'],
+                                    req['params']).encode('utf-8'))
                             raise
+                        else:
+                            if getattr(settings, 'SMOKNUR_PRINT_RESPONSE', False):
+                                size = getattr(settings, 'SMOKNUR_PRINT_RESPONSE_SIZE', 0)
+                                sys.stdout.write(
+                                    u'{0}, {1}\n'.format(
+                                        resp.status_code,
+                                        resp.content[:size]).encode('utf-8'))
 
                         self.assertTrue(
                             resp.status_code in (200, 302),
@@ -78,7 +95,7 @@ def test_runner(self):
                                 index,
                                 f,
                                 req['url'],
-                                req['params']))
+                                req['params']).encode('utf-8'))
 
 exclude_apps = getattr(settings, 'SMOKNUR_EXCLUDE_APPS', ())
 
@@ -92,24 +109,36 @@ for app in get_apps():
         os.path.dirname(app.__file__),
         'smoknur')
 
+
     if os.path.exists(path):
 
-        test_name = app.__package__.replace('.', '_').upper()
-        
-        attrs = {
-            'fixtures': [],
-            'smoknur_path': path,
-            'test': test_runner
-        }
+        smok_dirs = [
+            os.path.join(path, f)
+            for f in os.listdir(path)
+            if os.path.isdir(os.path.join(path, f))]
 
-        if NEW_DJANGO_TESTCASE:
-            attrs['_fixture_setup'] = _fixture_setup
+        smok_dirs.append(path)
 
-        for file_ in sorted(os.listdir(path)):
-            if file_.endswith('.json'):
-                attrs['fixtures'].append(os.path.join(path, file_))
+        for index, smok_dir in enumerate(smok_dirs):
 
-        globals()[test_name] = type(
-            test_name, 
-            (TransactionTestCase, ), 
-            attrs)    
+            test_name = u'{0}_{1}'.format(
+                app.__package__.replace('.', '_').upper(),
+                index).encode('utf-8')
+            
+            attrs = {
+                'fixtures': [],
+                'smoknur_path': smok_dir,
+                'test': test_runner
+            }
+
+            if NEW_DJANGO_TESTCASE:
+                attrs['_fixture_setup'] = _fixture_setup
+
+            for file_ in sorted(os.listdir(smok_dir)):
+                if file_.endswith('.json'):
+                    attrs['fixtures'].append(os.path.join(smok_dir, file_))
+
+            globals()[test_name] = type(
+                test_name, 
+                (TransactionTestCase, ), 
+                attrs)    
